# Chainlist
A list of EVM-based chains that also allows you to add chains to your favorite Web3 wallet. An alternative to the closing chainlist.org. 

Uses the data from https://github.com/ethereum-lists/chains

## Getting Started

### Development

To start a development server, run the following command

```bash
yarn run start
```

The server will be accessible on `localhost:8000`.

### Production

To build a static version of the site for production, run the following command

```bash
yarn run build
```

## Contributions
Contributions are very welcome! Feel free to open issues and PRs for missing features or potential bugs!

## License
This project is [MIT licensed](./LICENSE).
